Authors
-------

Roman Kalyakin <roman@kalyakin.com>

Based on `mongonose` plugin by Kapil Thangavelu.

Contributors
------------
 * Jay Luker (http://github.com/lbjay) <lbjay@reallywow.com>
 * Ziad Sawalha (http://github.com/ziadsawalha) 
 * John Paul Hayes (https://github.com/johnpaulhayes)
 * mefyl (https://github.com/mefyl)
 * Victor Varvaryuk (https://github.com/warvariuc)
 * Heikki Mikkolainen (https://github.com/jundi)
